@@ -106,7 +106,9 @@ func (r *ReconcileJaeger) Reconcile(request reconcile.Request) (reconcile.Result
 			// Request object not found, could have been deleted after reconcile request.
 			// Owned objects are automatically garbage collected. For additional cleanup logic use finalizers.
 			// Return and don't requeue
-			span.SetStatus(codes.NotFound)
+			if err := r.cleanConfigMaps(ctx, request.Name); err != nil {
+				return reconcile.Result{}, tracing.HandleError(err, span)
+			}
 			return reconcile.Result{}, nil
 		}
 		// Error reading the object - requeue the request.
